@@ -29,15 +29,27 @@ from nwp500.auth import (
     authenticate,
     refresh_access_token,
 )
+from nwp500.encoding import (
+    build_reservation_entry,
+    build_tou_period,
+    decode_price,
+    decode_season_bitfield,
+    decode_week_bitfield,
+    encode_price,
+    encode_season_bitfield,
+    encode_week_bitfield,
+)
 from nwp500.events import (
     EventEmitter,
     EventListener,
 )
 from nwp500.models import (
+    CurrentOperationMode,
     Device,
     DeviceFeature,
     DeviceInfo,
     DeviceStatus,
+    DhwOperationSetting,
     EnergyUsageData,
     EnergyUsageResponse,
     EnergyUsageTotal,
@@ -46,15 +58,14 @@ from nwp500.models import (
     MonthlyEnergyData,
     MqttCommand,
     MqttRequest,
-    OperationMode,
     TemperatureUnit,
     TOUInfo,
     TOUSchedule,
 )
-from nwp500.mqtt_client import (
-    MqttConnectionConfig,
-    NavienMqttClient,
-    PeriodicRequestType,
+from nwp500.mqtt_client import NavienMqttClient
+from nwp500.mqtt_utils import MqttConnectionConfig, PeriodicRequestType
+from nwp500.utils import (
+    log_performance,
 )
 
 __all__ = [
@@ -68,7 +79,8 @@ __all__ = [
     "FirmwareInfo",
     "TOUSchedule",
     "TOUInfo",
-    "OperationMode",
+    "DhwOperationSetting",
+    "CurrentOperationMode",
     "TemperatureUnit",
     "MqttRequest",
     "MqttCommand",
@@ -99,4 +111,15 @@ __all__ = [
     # Event Emitter
     "EventEmitter",
     "EventListener",
+    # Encoding utilities
+    "encode_week_bitfield",
+    "decode_week_bitfield",
+    "encode_season_bitfield",
+    "decode_season_bitfield",
+    "encode_price",
+    "decode_price",
+    "build_reservation_entry",
+    "build_tou_period",
+    # Utilities
+    "log_performance",
 ]
