@@ -1,24 +1,17 @@
 """
-API Client for Navien Smart Control REST API.
+Client for interacting with the Navien NWP500 API.
 
-This module provides a high-level client for interacting with the Navien Smart Control
-API, implementing all endpoints from the OpenAPI specification.
+This module provides an async HTTP client for device management and control.
 """
 
 import logging
-from collections.abc import Iterable
-from numbers import Real
-from typing import Any, Optional, Union
+from typing import Any, Optional
 
 import aiohttp
 
 from .auth import AuthenticationError, NavienAuthClient
 from .config import API_BASE_URL
-from .models import (
-    Device,
-    FirmwareInfo,
-    TOUInfo,
-)
+from .models import Device, FirmwareInfo, TOUInfo
 
 __author__ = "Emmanuel Levijarvi"
 __copyright__ = "Emmanuel Levijarvi"
@@ -34,7 +27,7 @@ class APIError(Exception):
         self,
         message: str,
         code: Optional[int] = None,
-        response: Optional[dict] = None,
+        response: Optional[dict[str, Any]] = None,
     ):
         self.message = message
         self.code = code
@@ -58,18 +51,6 @@ class NavienAPIClient:
         ...     devices = await api_client.list_devices()
     """
 
-    _WEEKDAY_ORDER = [
-        "Sunday",
-        "Monday",
-        "Tuesday",
-        "Wednesday",
-        "Thursday",
-        "Friday",
-        "Saturday",
-    ]
-    _WEEKDAY_NAME_TO_BIT = {name.lower(): 1 << idx for idx, name in enumerate(_WEEKDAY_ORDER)}
-    _MONTH_TO_BIT = {month: 1 << (month - 1) for month in range(1, 13)}
-
     def __init__(
         self,
         auth_client: NavienAuthClient,
@@ -96,24 +77,26 @@ class NavienAPIClient:
 
         self.base_url = base_url.rstrip("/")
         self._auth_client = auth_client
-        self._session = session or auth_client._session
+        self._session: aiohttp.ClientSession = session or auth_client._session  # type: ignore[assignment]
+        if self._session is None:
+            raise ValueError("auth_client must have an active session")
         self._owned_session = False  # Never own session when auth_client is provided
         self._owned_auth = False  # Never own auth_client
 
-    async def __aenter__(self):
-        """Async context manager entry - not required but supported for convenience."""
+    async def __aenter__(self) -> "NavienAPIClient":
+        """Enter async context manager."""
         return self
 
-    async def __aexit__(self, exc_type, exc_val, exc_tb):
-        """Async context manager exit - cleanup is handled by auth_client."""
+    async def __aexit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> None:
+        """Exit async context manager."""
         pass
 
     async def _make_request(
         self,
         method: str,
         endpoint: str,
-        json_data: Optional[dict] = None,
-        params: Optional[dict] = None,
+        json_data: Optional[dict[str, Any]] = None,
+        params: Optional[dict[str, Any]] = None,
     ) -> dict[str, Any]:
         """
         Make an authenticated API request.
@@ -149,7 +132,7 @@ class NavienAPIClient:
             async with self._session.request(
                 method, url, headers=headers, json=json_data, params=params
             ) as response:
-                response_data = await response.json()
+                response_data: dict[str, Any] = await response.json()
 
                 # Check for API errors
                 code = response_data.get("code", response.status)
@@ -317,7 +300,7 @@ class NavienAPIClient:
         data = response.get("data", {})
         tou_info = TOUInfo.from_dict(data)
 
-        _logger.info(f"Retrieved TOU info for {mac_address}")
+        _logger.info("Retrieved TOU info for device")
         return tou_info
 
     async def update_push_token(
@@ -385,155 +368,3 @@ class NavienAPIClient:
     def user_email(self) -> Optional[str]:
         """Get current user email."""
         return self._auth_client.user_email
-
-    # Helper utilities -------------------------------------------------
-
-    @staticmethod
-    def encode_week_bitfield(days: Iterable[Union[str, int]]) -> int:
-        """Convert a collection of day names or indices into the reservation bitfield."""
-        bitfield = 0
-        for value in days:
-            if isinstance(value, str):
-                key = value.strip().lower()
-                if key not in NavienAPIClient._WEEKDAY_NAME_TO_BIT:
-                    raise ValueError(f"Unknown weekday: {value}")
-                bitfield |= NavienAPIClient._WEEKDAY_NAME_TO_BIT[key]
-            elif isinstance(value, int):
-                if 0 <= value <= 6:
-                    bitfield |= 1 << value
-                elif 1 <= value <= 7:
-                    bitfield |= 1 << (value - 1)
-                else:
-                    raise ValueError("Day index must be between 0-6 or 1-7")
-            else:
-                raise TypeError("Weekday values must be strings or integers")
-        return bitfield
-
-    @staticmethod
-    def decode_week_bitfield(bitfield: int) -> list[str]:
-        """Decode a reservation bitfield back into a list of weekday names."""
-        days: list[str] = []
-        for idx, name in enumerate(NavienAPIClient._WEEKDAY_ORDER):
-            if bitfield & (1 << idx):
-                days.append(name)
-        return days
-
-    @staticmethod
-    def encode_season_bitfield(months: Iterable[int]) -> int:
-        """Encode a collection of month numbers (1-12) into a TOU season bitfield."""
-        bitfield = 0
-        for month in months:
-            if month not in NavienAPIClient._MONTH_TO_BIT:
-                raise ValueError("Month values must be in the range 1-12")
-            bitfield |= NavienAPIClient._MONTH_TO_BIT[month]
-        return bitfield
-
-    @staticmethod
-    def decode_season_bitfield(bitfield: int) -> list[int]:
-        """Decode a TOU season bitfield into the corresponding month numbers."""
-        months: list[int] = []
-        for month, mask in NavienAPIClient._MONTH_TO_BIT.items():
-            if bitfield & mask:
-                months.append(month)
-        return months
-
-    @staticmethod
-    def encode_price(value: Real, decimal_point: int) -> int:
-        """Encode a price into the integer representation expected by the device."""
-        if decimal_point < 0:
-            raise ValueError("decimal_point must be >= 0")
-        scale = 10**decimal_point
-        return int(round(float(value) * scale))
-
-    @staticmethod
-    def decode_price(value: int, decimal_point: int) -> float:
-        """Decode an integer price value using the provided decimal point."""
-        if decimal_point < 0:
-            raise ValueError("decimal_point must be >= 0")
-        scale = 10**decimal_point
-        return value / scale if scale else float(value)
-
-    @staticmethod
-    def build_reservation_entry(
-        *,
-        enabled: Union[bool, int],
-        days: Iterable[Union[str, int]],
-        hour: int,
-        minute: int,
-        mode_id: int,
-        param: int,
-    ) -> dict[str, int]:
-        """Build a reservation payload entry matching the documented MQTT format."""
-        if not 0 <= hour <= 23:
-            raise ValueError("hour must be between 0 and 23")
-        if not 0 <= minute <= 59:
-            raise ValueError("minute must be between 0 and 59")
-        if mode_id < 0:
-            raise ValueError("mode_id must be non-negative")
-
-        if isinstance(enabled, bool):
-            enable_flag = 1 if enabled else 2
-        elif enabled in (1, 2):
-            enable_flag = int(enabled)
-        else:
-            raise ValueError("enabled must be True/False or 1/2")
-
-        week_bitfield = NavienAPIClient.encode_week_bitfield(days)
-
-        return {
-            "enable": enable_flag,
-            "week": week_bitfield,
-            "hour": hour,
-            "min": minute,
-            "mode": mode_id,
-            "param": param,
-        }
-
-    @staticmethod
-    def build_tou_period(
-        *,
-        season_months: Iterable[int],
-        week_days: Iterable[Union[str, int]],
-        start_hour: int,
-        start_minute: int,
-        end_hour: int,
-        end_minute: int,
-        price_min: Union[int, Real],
-        price_max: Union[int, Real],
-        decimal_point: int,
-    ) -> dict[str, int]:
-        """Build a TOU period entry consistent with MQTT command requirements."""
-        for label, value, upper in (
-            ("start_hour", start_hour, 23),
-            ("end_hour", end_hour, 23),
-        ):
-            if not 0 <= value <= upper:
-                raise ValueError(f"{label} must be between 0 and {upper}")
-        for label, value in (("start_minute", start_minute), ("end_minute", end_minute)):
-            if not 0 <= value <= 59:
-                raise ValueError(f"{label} must be between 0 and 59")
-
-        week_bitfield = NavienAPIClient.encode_week_bitfield(week_days)
-        season_bitfield = NavienAPIClient.encode_season_bitfield(season_months)
-
-        if isinstance(price_min, Real) and not isinstance(price_min, int):
-            encoded_min = NavienAPIClient.encode_price(price_min, decimal_point)
-        else:
-            encoded_min = int(price_min)
-
-        if isinstance(price_max, Real) and not isinstance(price_max, int):
-            encoded_max = NavienAPIClient.encode_price(price_max, decimal_point)
-        else:
-            encoded_max = int(price_max)
-
-        return {
-            "season": season_bitfield,
-            "week": week_bitfield,
-            "startHour": start_hour,
-            "startMinute": start_minute,
-            "endHour": end_hour,
-            "endMinute": end_minute,
-            "priceMin": encoded_min,
-            "priceMax": encoded_max,
-            "decimalPoint": decimal_point,
-        }
